=====
Customforms
=====

Customforms is a simple Django app to attach forms to pages.

Quick start
-----------

1. Add "customforms" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'customforms',
    ]

2. Check out the example app for usage.

3. Run `python manage.py migrate` once your models are set up.
